@@ -1,6 +1,4 @@
-use super::*;
-
-use CompileErrorKind::*;
+use {super::*, CompileErrorKind::*};
 
 pub(crate) struct AssignmentResolver<'src: 'run, 'run> {
   assignments: &'run Table<'src, Assignment<'src>>,
@@ -36,7 +34,7 @@ impl<'src: 'run, 'run> AssignmentResolver<'src, 'run> {
       self.resolve_expression(&assignment.value)?;
       self.evaluated.insert(name);
     } else {
-      let message = format!("attempted to resolve unknown assignment `{}`", name);
+      let message = format!("attempted to resolve unknown assignment `{name}`");
       let token = Token {
         src: "",
         offset: 0,
