@@ -3,6 +3,7 @@
   clippy::default_trait_access,
   clippy::doc_markdown,
   clippy::enum_glob_use,
+  clippy::let_underscore_untyped,
   clippy::missing_errors_doc,
   clippy::needless_pass_by_value,
   clippy::non_ascii_literal,
@@ -18,7 +19,7 @@ pub(crate) use {
     alias::Alias, analyzer::Analyzer, assignment::Assignment,
     assignment_resolver::AssignmentResolver, ast::Ast, attribute::Attribute, binding::Binding,
     color::Color, color_display::ColorDisplay, command_ext::CommandExt,
-    compile_error::CompileError, compile_error_kind::CompileErrorKind,
+    compile_error::CompileError, compile_error_kind::CompileErrorKind, compiler::Compiler,
     conditional_operator::ConditionalOperator, config::Config, config_error::ConfigError,
     count::Count, delimiter::Delimiter, dependency::Dependency, dump_format::DumpFormat,
     enclosure::Enclosure, error::Error, evaluator::Evaluator, expression::Expression,
