@@ -179,9 +179,7 @@ impl Subcommand {
   ) -> Result<(&'src str, Ast<'src>, Justfile<'src>), Error<'src>> {
     let src = loader.load(&search.justfile)?;
 
-    let tokens = Lexer::lex(src)?;
-    let ast = Parser::parse(&tokens)?;
-    let justfile = Analyzer::analyze(&ast)?;
+    let (ast, justfile) = Compiler::compile(src)?;
 
     if config.verbosity.loud() {
       for warning in &justfile.warnings {
@@ -285,8 +283,7 @@ impl Subcommand {
         Ok(())
       } else {
         Err(Error::internal(format!(
-          "Failed to find text:\n{}\n…in completion script:\n{}",
-          needle, haystack
+          "Failed to find text:\n{needle}\n…in completion script:\n{haystack}"
         )))
       }
     }
