@@ -70,8 +70,7 @@ impl<'src> ColorDisplay for Token<'src> {
         if self.offset != self.src.len() {
           write!(
             f,
-            "internal error: Error has invalid line number: {}",
-            line_number
+            "internal error: Error has invalid line number: {line_number}"
           )?;
         }
       }
