@@ -1,4 +1,4 @@
-use crate::common::*;
+use super::*;
 
 test! {
   name: then_branch_unevaluated,
@@ -132,7 +132,7 @@ test! {
   ",
   stdout: "",
   stderr: "
-    error: Expected '!=', '==', or '+', but found identifier
+    error: Expected '!=', '==', '=~', '+', or '/', but found identifier
       |
     1 | a := if '' a '' { '' } else { b }
       |            ^
@@ -168,3 +168,33 @@ test! {
   stdout: "b\n",
   stderr: "echo b\n",
 }
+
+test! {
+  name: missing_else,
+  justfile: "
+  TEST := if path_exists('/bin/bash') == 'true' {'yes'}
+  ",
+  stdout: "",
+  stderr: "
+    error: Expected keyword `else` but found `end of line`
+      |
+    1 | TEST := if path_exists('/bin/bash') == 'true' {'yes'}
+      |                                                      ^
+  ",
+  status: EXIT_FAILURE,
+}
+
+test! {
+  name: incorrect_else_identifier,
+  justfile: "
+  TEST := if path_exists('/bin/bash') == 'true' {'yes'} els {'no'}
+  ",
+  stdout: "",
+  stderr: "
+    error: Expected keyword `else` but found identifier `els`
+      |
+    1 | TEST := if path_exists('/bin/bash') == 'true' {'yes'} els {'no'}
+      |                                                       ^^^
+  ",
+  status: EXIT_FAILURE,
+}
