@@ -413,7 +413,7 @@ test! {
 
 fn assert_eval_eq(expression: &str, result: &str) {
   Test::new()
-    .justfile(format!("x := {}", expression))
+    .justfile(format!("x := {expression}"))
     .args(["--evaluate", "x"])
     .stdout(result)
     .unindent_stdout(false)
