@@ -234,19 +234,13 @@ impl Test {
 
     if let Some(ref stdout_regex) = self.stdout_regex {
       if !stdout_regex.is_match(output_stdout) {
-        panic!(
-          "Stdout regex mismatch:\n{:?}\n!~=\n/{:?}/",
-          output_stderr, stdout_regex
-        );
+        panic!("Stdout regex mismatch:\n{output_stderr:?}\n!~=\n/{stdout_regex:?}/");
       }
     }
 
     if let Some(ref stderr_regex) = self.stderr_regex {
       if !stderr_regex.is_match(output_stderr) {
-        panic!(
-          "Stderr regex mismatch:\n{:?}\n!~=\n/{:?}/",
-          output_stderr, stderr_regex
-        );
+        panic!("Stderr regex mismatch:\n{output_stderr:?}\n!~=\n/{stderr_regex:?}/");
       }
     }
 
